# rrlfe

A code base for generating and applying calibrations for retrieving [Fe/H] from low-res spectra of RR Lyrae variable stars. See https://rrlfe.readthedocs.io/ for documentation.

[![Coverage Status](https://coveralls.io/repos/github/mwanakijiji/rrlfe/badge.svg?branch=main)](https://coveralls.io/github/mwanakijiji/rrlfe?branch=main)

## Attribution ##

If this code has been useful for your work, please cite the source in the following BibTeX entry:

    @article{esposito2018,
        Adsurl = {},
        Author = {},
        Doi = {},
        Eid = {},
        Journal = {},
        Keywords = {},
        Month = ,
        Pages = {},
        Title = {{}},
        Volume = ,
        Year = ,
        Bdsk-Url-1 = {}
	}
